function p = mergepts(p3,p2)
%
% mergepts: merges 3D points and 2D points (for Faugeras call argument)
% On input:
%     p3: array of 3D points (m by 3)
%     p2: array of 2D points (m by 2)
% On output:
%     p: merged points (m by 5)
% Call:
%     p = mergepts(p3,p2)
%

[m,n] = size(p3);
for i1 = 1:n
  p(i1,1:3) = p3(1:3,i1)';
  p(i1,4:5) = p2(1:2,i1)';
end;
